@@ -217,9 +217,9 @@ parent_set_callback (GtkWidget *widget,
 
 #ifdef DEBUG_GEOMETRY
   if (old_parent)
-    g_signal_handlers_disconnect_by_func (old_parent, G_CALLBACK (parent_size_request), screen);
-  if (GTK_WIDGET (screen)->parent)
-    g_signal_connect (GTK_WIDGET (screen)->parent, "size-request", G_CALLBACK (parent_size_request), screen);
+    g_signal_handlers_disconnect_by_func (old_parent, G_CALLBACK (parent_size_request), widget);
+  if (widget->parent)
+    g_signal_connect (widget->parent, "size-request", G_CALLBACK (parent_size_request), widget);
 #endif
 }
 
@@ -1496,7 +1496,7 @@ terminal_screen_button_press_event (GtkWidget      *widget,
   int char_width, char_height;
   gboolean dingus_button;
   char *matched_string;
-  int matched_flavor;
+  int matched_flavor = 0;
   guint state;
 
   state = event->state & gtk_accelerator_get_default_mod_mask ();
