@@ -856,8 +856,7 @@ handle_tab_droped_on_desktop (GtkNotebook *source_notebook,
   g_return_val_if_fail (TERMINAL_IS_WINDOW (source_window), NULL);
 
   new_window = terminal_app_new_window (terminal_app_get (),
-                                        gtk_widget_get_screen (GTK_WIDGET (source_window)),
-                                        NULL /* FIXME? */);
+                                        gtk_widget_get_screen (GTK_WIDGET (source_window)));
   new_priv = new_window->priv;
   new_priv->present_on_insert = TRUE;
 
@@ -1942,7 +1941,7 @@ terminal_window_set_menubar_visible (TerminalWindow *window,
   if (priv->active_screen)
     {
 #ifdef DEBUG_GEOMETRY
-      g_fprintf (stderr,"setting size after toggling menubar visibility\n");
+      g_printerr ("setting size after toggling menubar visibility\n");
 #endif
       terminal_window_set_size (window, priv->active_screen, TRUE);
     }
@@ -2005,7 +2004,7 @@ terminal_window_set_size_force_grid (TerminalWindow *window,
   gtk_widget_size_request (widget, &widget_request);
 
 #ifdef DEBUG_GEOMETRY
-  g_fprintf (stderr,"set size: toplevel %dx%d widget %dx%d\n",
+  g_printerr ("set size: toplevel %dx%d widget %dx%d\n",
            toplevel_request.width, toplevel_request.height,
            widget_request.width, widget_request.height);
 #endif
@@ -2027,7 +2026,7 @@ terminal_window_set_size_force_grid (TerminalWindow *window,
   h += ypad + char_height * grid_height;
 
 #ifdef DEBUG_GEOMETRY
-  g_fprintf (stderr,"set size: grid %dx%d force %dx%d setting %dx%d pixels\n",
+  g_printerr ("set size: grid %dx%d force %dx%d setting %dx%d pixels\n",
            grid_width, grid_height, force_grid_width, force_grid_height, w, h);
 #endif
 
@@ -2086,7 +2085,7 @@ terminal_window_set_active (TerminalWindow *window,
 
   /* set size of window to current grid size */
 #ifdef DEBUG_GEOMETRY
-  g_fprintf (stderr,"setting size after flipping notebook pages\n");
+  g_printerr ("setting size after flipping notebook pages\n");
 #endif
   terminal_window_set_size (window, screen, TRUE);
 
@@ -2347,7 +2346,7 @@ terminal_window_update_geometry (TerminalWindow *window)
                                      GDK_HINT_BASE_SIZE);
 
 #ifdef DEBUG_GEOMETRY
-      g_fprintf (stderr,"hints: base %dx%d min %dx%d inc %d %d\n",
+      g_printerr ("hints: base %dx%d min %dx%d inc %d %d\n",
                hints.base_width,
                hints.base_height,
                hints.min_width,
@@ -2363,7 +2362,7 @@ terminal_window_update_geometry (TerminalWindow *window)
 #ifdef DEBUG_GEOMETRY
   else
     {
-      g_fprintf (stderr,"hints: increment unchanged, not setting\n");
+      g_printerr ("hints: increment unchanged, not setting\n");
     }
 #endif
 }
@@ -2394,15 +2393,16 @@ file_new_window_callback (GtkAction *action,
   terminal_screen_get_size (priv->active_screen, &width, &height);
   geometry = g_strdup_printf ("%dx%d", width, height);
 
-  new_window = terminal_app_new_window (app, gtk_widget_get_screen (GTK_WIDGET (window)),
-                                        geometry);
-  g_free (geometry);
+  new_window = terminal_app_new_window (app, gtk_widget_get_screen (GTK_WIDGET (window)));
 
   terminal_app_new_terminal (app, new_window, profile,
                              NULL, NULL,
                              terminal_screen_get_working_dir (priv->active_screen),
                              1.0);
 
+  gtk_window_parse_geometry (GTK_WINDOW (window), geometry);
+  g_free (geometry);
+
   gtk_window_present (GTK_WINDOW (new_window));
 }
 
@@ -2866,12 +2866,13 @@ tabs_detach_tab_callback (GtkAction *action,
   terminal_screen_get_size (screen, &width, &height);
   geometry = g_strdup_printf ("%dx%d", width, height);
 
-  new_window = terminal_app_new_window (app, gtk_widget_get_screen (GTK_WIDGET (window)),
-                                        geometry);
-  g_free (geometry);
+  new_window = terminal_app_new_window (app, gtk_widget_get_screen (GTK_WIDGET (window)));
 
   terminal_window_move_screen (window, new_window, screen, -1);
 
+  gtk_window_parse_geometry (GTK_WINDOW (window), geometry);
+  g_free (geometry);
+
   gtk_window_present_with_time (GTK_WINDOW (new_window), gtk_get_current_event_time ());
 }
 
