@@ -45,6 +45,7 @@
 #include <time.h>
 #include <gdk/gdkx.h>
 
+#define ACT_IID "OAFIID:GNOME_Terminal_Factory"
 
 /* Settings storage works as follows:
  *   /apps/gnome-terminal/global/
@@ -70,7 +71,7 @@
 
 static gboolean initialization_complete = FALSE;
 static GSList *pending_new_terminal_events = NULL;
-static gboolean use_factory;
+static BonoboListener *listener = NULL;
 
 typedef struct
 {
@@ -983,7 +984,7 @@ new_terminal_with_options (TerminalApp *app,
       g_assert (iw->tabs);
 
       /* Create & setup new window */
-      window = terminal_app_new_window (app, screen, iw->geometry);
+      window = terminal_app_new_window (app, screen);
 
       if (results->startup_id)
         terminal_window_set_startup_id (window, results->startup_id);
@@ -1030,6 +1031,12 @@ new_terminal_with_options (TerminalApp *app,
             terminal_window_switch_screen (window, screen);
         }
 
+      if (iw->geometry)
+        {
+          if (!gtk_window_parse_geometry (GTK_WINDOW (window), iw->geometry))
+            g_printerr (_("Invalid geometry string \"%s\"\n"), iw->geometry);
+        }
+
       gtk_window_present (GTK_WINDOW (window));
     }
 }
@@ -1178,8 +1185,7 @@ main (int argc, char **argv)
   
   option_parsing_results_apply_directory_defaults (parsing_results);
 
-  use_factory = parsing_results->use_factory;
-  if (use_factory)
+  if (parsing_results->use_factory)
     {
       char *cwd;
       
@@ -1216,7 +1222,7 @@ main (int argc, char **argv)
  
   g_assert (parsing_results->post_execute_args == NULL);
 
-  terminal_app_initialize (use_factory);
+  terminal_app_initialize (parsing_results->use_factory);
   g_signal_connect (terminal_app_get (), "quit", G_CALLBACK (gtk_main_quit), NULL);
 
   new_terminal_with_options (terminal_app_get (), parsing_results);
@@ -1230,6 +1236,9 @@ main (int argc, char **argv)
 
   terminal_app_shutdown ();
 
+  if (listener)
+    bonobo_activation_active_server_unregister (ACT_IID, BONOBO_OBJREF (listener));
+
   g_object_unref (program);
 
   return 0;
@@ -1733,13 +1742,10 @@ terminal_new_event (BonoboListener    *listener,
     handle_new_terminal_events ();
 }
 
-#define ACT_IID "OAFIID:GNOME_Terminal_Factory"
-
 static Bonobo_RegistrationResult
 terminal_register_as_factory (void)
 {
   char *per_display_iid;
-  BonoboListener *listener;
   Bonobo_RegistrationResult result;
 
   listener = bonobo_listener_new (terminal_new_event, NULL);
@@ -1753,6 +1759,11 @@ terminal_register_as_factory (void)
   if (result != Bonobo_ACTIVATION_REG_SUCCESS)
     bonobo_object_unref (BONOBO_OBJECT (listener));
 
+#ifdef DEBUG_FACTORY
+  if (result == Bonobo_ACTIVATION_REG_SUCCESS)
+    g_print ("Successfully registered factory \"%s\"\n", per_display_iid);
+#endif
+
   g_free (per_display_iid);
 
   return result;
@@ -1775,6 +1786,9 @@ terminal_invoke_factory (int argc, char **argv)
         g_printerr (_("Error registering terminal with the activation service; factory mode disabled.\n"));
         return FALSE;
       case Bonobo_ACTIVATION_REG_ALREADY_ACTIVE:
+#ifdef DEBUG_FACTORY
+        g_print ("Factory found; forwarding request\n");
+#endif
         /* lets use it then */
         break;
     }
